==> gromacs_2021.4.orig.tar.gz: gromacs-2021.4/src/gromacs/pbcutil/pbcenums.cpp <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2019, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*!\file
 * \internal
 * \brief
 * Implements getters for enum names.
 *
 * \author Paul Bauer <paul.bauer.q@gmail.com>
 * \ingroup module_pbcutil
 */

#include "gmxpre.h"

#include "pbcenums.h"

#include "gromacs/utility/enumerationhelpers.h"

namespace gmx
{

/*! \brief Names for different centering types.
 *
 * Those names need to be in sync with the CenteringType enum class
 * and reflect the same fields there.
 */
static EnumerationArray<CenteringType, const char*> c_centeringTypeShortNames = {
    { "Triclinic", "Rectangular", "Zero-Based" }
};

/*! \brief Names for different centering types.
 *
 * Those names need to be in sync with the UnitCellType enum class
 * and reflect the same fields there.
 */
static EnumerationArray<UnitCellType, const char*> c_unitCellTypeShortNames = {
    { "Triclinic", "Rectangular", "Compact" }
};

const char* centerTypeNames(CenteringType type)
{
    return c_centeringTypeShortNames[type];
}

const char* unitCellTypeNames(UnitCellType type)
{
    return c_unitCellTypeShortNames[type];
}

} // namespace gmx

==> gromacs_2022.5.orig.tar.gz: gromacs-2022.5/src/gromacs/pbcutil/pbcenums.cpp <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright 2019- The GROMACS Authors
 * and the project initiators Erik Lindahl, Berk Hess and David van der Spoel.
 * Consult the AUTHORS/COPYING files and https://www.gromacs.org for details.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * https://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at https://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out https://www.gromacs.org.
 */
/*!\file
 * \internal
 * \brief
 * Implements getters for enum names.
 *
 * \author Paul Bauer <paul.bauer.q@gmail.com>
 * \ingroup module_pbcutil
 */

#include "gmxpre.h"

#include "pbcenums.h"

#include "gromacs/utility/enumerationhelpers.h"

namespace gmx
{

const char* centerTypeNames(CenteringType type)
{
    constexpr EnumerationArray<CenteringType, const char*> c_centeringTypeShortNames = {
        "Triclinic", "Rectangular", "Zero-Based"
    };
    return c_centeringTypeShortNames[type];
}

const char* unitCellTypeNames(UnitCellType type)
{
    constexpr EnumerationArray<UnitCellType, const char*> c_unitCellTypeShortNames = {
        "Triclinic", "Rectangular", "Compact"
    };
    return c_unitCellTypeShortNames[type];
}

} // namespace gmx
